@@ -153,7 +153,12 @@ class ProxyManager:
                     try:
                         timer.start()
                         result_future = self._loop.run_in_executor(
-                            self._executor, functools.partial(fn, session, end_event, *args))
+                            self._executor, functools.partial(fn, session, *args))
+
+                        while not result_future.done():
+                            await asyncio.sleep(0.1)
+                            if end_event.is_set():
+                                return None
 
                         result = await result_future
                         timer.stop()
